.. py3o.template documentation master file, created by
   sphinx-quickstart on Wed Dec  4 15:14:05 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to py3o.template's documentation!
=========================================

Contents:

.. toctree::
   :maxdepth: 2

   pythoncode.rst
   templating.rst
   autodoc.rst



.. This below section is commented out...
    Indices and tables
    ==================

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`

